@@ -1,5 +1,5 @@
 package Net::Stomp::MooseHelpers::CanConnect;
-$Net::Stomp::MooseHelpers::CanConnect::VERSION = '2.9';
+$Net::Stomp::MooseHelpers::CanConnect::VERSION = '3.0';
 {
   $Net::Stomp::MooseHelpers::CanConnect::DIST = 'Net-Stomp-MooseHelpers';
 }
@@ -137,7 +137,7 @@ Net::Stomp::MooseHelpers::CanConnect - role for classes that connect via Net::St
 
 =head1 VERSION
 
-version 2.9
+version 3.0
 
 =head1 SYNOPSIS
 
@@ -209,12 +209,28 @@ that is, an arrayref of hashrefs, each of which describes how to
 connect to a single server. Defaults to C<< [ { hostname =>
 'localhost', port => 61613 } ] >>.
 
+If a server requires TLS, you can do C<< [ { hostname => $hostname,
+port => $port, ssl =>1 } ] >>.
+
+If a server requires authentication, you can pass the credentials in
+the C<connect_headers> slot here: C<< [ { hostname => $hostname, port
+=> $port, connect_headers => { login => $login, passcode => $passcode
+} } ] >>.
+
+If all servers require the same authentication, you can instead set
+the credentials in the L<< /C<connect_headers> >> attribute.
+
 =head2 C<connect_headers>
 
 Global setting for connection headers (passed to
 L<Net::Stomp/connect>). Can be overridden by the C<connect_headers>
 slot in each element of L</servers>. Defaults to the empty hashref.
 
+If all servers require the same authentication, you can set the
+credentials here: C<< { login => $login, passcode => $passcode }
+>>. If different servers require different credentials, you should set
+them in the L<< /C<servers> >> attribute instead.
+
 =head1 METHODS
 
 =head2 C<current_server>
